@@ -22,7 +22,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '2.4.56'
+__version__ = '2.4.61'
 
 # ----------------------------------------------------------------------------
 
@@ -167,7 +167,6 @@ from ccxt.paymium import paymium                                      # noqa: F4
 from ccxt.phemex import phemex                                        # noqa: F401
 from ccxt.poloniex import poloniex                                    # noqa: F401
 from ccxt.probit import probit                                        # noqa: F401
-from ccxt.qtrade import qtrade                                        # noqa: F401
 from ccxt.ripio import ripio                                          # noqa: F401
 from ccxt.stex import stex                                            # noqa: F401
 from ccxt.therock import therock                                      # noqa: F401
@@ -280,7 +279,6 @@ exchanges = [
     'phemex',
     'poloniex',
     'probit',
-    'qtrade',
     'ripio',
     'stex',
     'therock',
